Attack of the Ocrs
==================

Introduction
------------
This is a command line fantasy war game!

Documentation
-------------
Documentation can be found...

Example Usag
------------
Here is an example to import the modules from this package.

..code::python

from wargame.attackoftheocrs import AttackOfTheOcrs
game=AttackOfTheOcrs()
game.play()

LICENSE
-------
See LICENSE.txt file.